@@ -2,34 +2,28 @@ from dataclasses import dataclass, field
 
 import requests
 
-DEFAULT_CONFIG = {
-    'tts': False,
-    'stripSSML': True,
-    'stopAll': True,
-    'stopTypes': [],
-    'excludeTypes': [
-        'block',
-        'debug',
-        'flow',
-    ]
-}
+from .defaults import (
+    API_BASE_URL,
+    DEFAULT_INTERACT_CONFIG,
+)
 
 
 @dataclass
 class Interact:
     api_key: str
     user_id: str
-    api_base_url: str = 'https://general-runtime.voiceflow.com'
+    version_id: str
     headers: dict = field(init=False)
 
     def __post_init__(self):
         self.headers = {
             'Authorization': self.api_key,
+            'versionID': self.version_id,
         }
 
     def interact_request(self, body: dict) -> dict:
         response = requests.post(
-            f'{self.api_base_url}/state/user/{self.user_id}/interact',
+            f'{API_BASE_URL}/state/user/{self.user_id}/interact',
             json=body,
             headers=self.headers,
         )
@@ -40,7 +34,7 @@ class Interact:
             'action': {
                 'type': 'launch',
             },
-            'config': config or DEFAULT_CONFIG,
+            'config': config or DEFAULT_INTERACT_CONFIG,
         }
         response = self.interact_request(body=body)
         return response
@@ -53,7 +47,7 @@ class Interact:
                 'type': 'text',
                 'payload': user_input,
             },
-            'config': config or DEFAULT_CONFIG,
+            'config': config or DEFAULT_INTERACT_CONFIG,
         }
         response = self.interact_request(body=body)
         return response
